Clazz.declarePackage("JSV.api");
Clazz.declareInterface(JSV.api, "JSVTreeNode");
;//5.0.1-v2 Tue Aug 13 23:00:42 EDT 2024
